@@ -1182,21 +1182,24 @@ class Query(object):
 
         @raise WebserviceError: if the request is unsuccessful
         """
-        path = self.get_results_path()
-        params = self.to_query_params()
+
+        to_run = self.clone()
+
+        if len(to_run.views) == 0:
+            to_run.add_view(to_run.root)
+
+        path = to_run.get_results_path()
+        params = to_run.to_query_params()
         params["start"] = start
         if size:
             params["size"] = size
         if summary_path:
-            params["summaryPath"] = self.prefix_path(summary_path)
+            params["summaryPath"] = to_run.prefix_path(summary_path)
             row = "jsonrows" 
 
-        if len(self.views) == 0:
-            self.add_view(self.root)
-
-        view = self.views
-        cld = self.root
-        return self.service.get_results(path, params, row, view, cld)
+        view = to_run.views
+        cld = to_run.root
+        return to_run.service.get_results(path, params, row, view, cld)
 
     def rows(self, start=0, size=None):
         """
@@ -1507,7 +1510,7 @@ class Query(object):
         @return: same class as caller
         """
         newobj = self.__class__(self.model)
-        for attr in ["joins", "views", "_sort_order_list", "_logic", "path_descriptions", "constraint_dict"]:
+        for attr in ["joins", "views", "_sort_order_list", "_logic", "path_descriptions", "constraint_dict", "uncoded_constraints"]:
             setattr(newobj, attr, deepcopy(getattr(self, attr)))
 
         for attr in ["name", "description", "service", "do_verification", "constraint_factory", "root"]:
