@@ -51,7 +51,8 @@ class LiveListTest(unittest.TestCase):
     def testListsFromFlyMine(self):
         s = Service("www.flymine.org/query")
         all_lists = s.get_all_lists()
-        self.assertEqual("CURRENT", all_lists[0].status)
+        possible_statuses = set(["CURRENT", "TO_UPGRADE"])
+        self.assertTrue(set((l.status for l in all_lists)) <= possible_statuses)
 
     def testListTagAdding(self):
         s = self.SERVICE
@@ -134,15 +135,15 @@ class LiveListTest(unittest.TestCase):
 
         got = [row[:3] + row[4:] for row in l.to_attribute_query().rows()]
         self.assertEqual(got, expected)
-        
 
         # Test iteration:
-        got = [x.age for x in l]
-        self.assertEqual([37, 41, 44, 53, 55], got)
+        got = set([x.age for x in l])
+        expected_ages = set([37, 41, 44, 53, 55])
+        self.assertEqual(expected_ages, got)
 
-        self.assertEqual(37, l[0].age)
-        self.assertEqual(55, l[-1].age)
-        self.assertEqual(44, l[2].age)
+        self.assertTrue(l[0].age in expected_ages)
+        self.assertTrue(l[-1].age in expected_ages)
+        self.assertTrue(l[2].age in expected_ages)
         self.assertRaises(IndexError, lambda: l[5])
         self.assertRaises(IndexError, lambda: l[-6])
         self.assertRaises(IndexError, lambda: l["foo"])
@@ -325,7 +326,7 @@ class LiveListTest(unittest.TestCase):
         self.assertEqual(self.SERVICE.get_list_count(), self.initialListCount)
 
 class LiveListTestWithTokens(LiveListTest):
-    SERVICE = Service(LiveListTest.TEST_ROOT, token="T1h3x3Ndsa4ambE9x5Q5G4famKl")
+    SERVICE = Service(LiveListTest.TEST_ROOT, token="test-user-token")
 
 if __name__ == '__main__':
     unittest.main()
